@@ -111,7 +111,7 @@ class Database(object):
     :: Database
     """
 
-    def __init__(self, dsn:str=None, connector:adapters.Adapter = None):
+    def __init__(self, dsn:str=None, adapter:adapters.Adapter = None):
         """
         Connect database 
 
@@ -123,17 +123,17 @@ class Database(object):
                 - mysql://username:password@hostname:port/dbname
                 - mariadb://username:password@hostname:port/dbname
         """
-        if not dsn and not connector:
-            connector = adapters.SQLiteAdapter(file=":memory:")
+        if not dsn and not adapter:
+            adapter = adapters.SQLiteAdapter(file=":memory:")
         elif dsn:
             _ = urlparse(dsn)
             # scheme, username, password, hostname, port, path.strip("/")
             if _.scheme == "sqlite":
-                connector = adapters.SQLiteAdapter(dsn)
+                adapter = adapters.SQLiteAdapter(dsn)
             elif _.scheme in ["mysql", "mariadb"]:
-                connector = adapters.MySQLAdapter(dsn)
+                adapter = adapters.MySQLAdapter(dsn)
 
-        self.conn = connector
+        self.conn = adapter
 
     def select(self, name):
         """
